'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isPanelCollapsed = exports.getSearchPanelPageSize = exports.getSearchPageSize = exports.getQuickSearchVocabulary = exports.getQuickSearchRecordType = exports.getSearchPageVocabulary = exports.getSearchPageRecordType = undefined;

var _immutable = require('immutable');

var _immutable2 = _interopRequireDefault(_immutable);

var _prefs = require('../actions/prefs');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = function () {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : _immutable2.default.Map();
  var action = arguments[1];

  switch (action.type) {
    case _prefs.PREFS_LOADED:
      return action.payload || state;
    case _prefs.COLLAPSE_PANEL:
      return state.setIn(['panels', action.meta.recordType, action.meta.name, 'collapsed'], action.payload);
    case _prefs.SET_SEARCH_PAGE_RECORD_TYPE:
      return state.setIn(['searchPage', 'recordType'], action.payload);
    case _prefs.SET_SEARCH_PAGE_VOCABULARY:
      return state.setIn(['searchPage', 'vocabulary', state.getIn(['searchPage', 'recordType'])], action.payload);
    case _prefs.SET_QUICK_SEARCH_RECORD_TYPE:
      return state.setIn(['quickSearch', 'recordType'], action.payload);
    case _prefs.SET_QUICK_SEARCH_VOCABULARY:
      return state.setIn(['quickSearch', 'vocabulary', state.getIn(['quickSearch', 'recordType'])], action.payload);
    case _prefs.SET_SEARCH_PAGE_SIZE:
      return state.set('searchPageSize', action.payload);
    case _prefs.SET_SEARCH_PANEL_PAGE_SIZE:
      return state.setIn(['panels', action.meta.recordType, action.meta.name, 'pageSize'], action.payload);
    default:
      return state;
  }
};

var getSearchPageRecordType = exports.getSearchPageRecordType = function getSearchPageRecordType(state) {
  return state.getIn(['searchPage', 'recordType']);
};

var getSearchPageVocabulary = exports.getSearchPageVocabulary = function getSearchPageVocabulary(state, recordType) {
  return state.getIn(['searchPage', 'vocabulary', recordType]);
};

var getQuickSearchRecordType = exports.getQuickSearchRecordType = function getQuickSearchRecordType(state) {
  return state.getIn(['quickSearch', 'recordType']);
};

var getQuickSearchVocabulary = exports.getQuickSearchVocabulary = function getQuickSearchVocabulary(state, recordType) {
  return state.getIn(['quickSearch', 'vocabulary', recordType]);
};

var getSearchPageSize = exports.getSearchPageSize = function getSearchPageSize(state) {
  return state.get('searchPageSize');
};

var getSearchPanelPageSize = exports.getSearchPanelPageSize = function getSearchPanelPageSize(state, recordType, name) {
  return state.getIn(['panels', recordType, name, 'pageSize']);
};

var isPanelCollapsed = exports.isPanelCollapsed = function isPanelCollapsed(state, recordType, name) {
  return state.getIn(['panels', recordType, name, 'collapsed']);
};